#===========================================================
# E1: Steuerungsfunktionen
#===========================================================

#===========================================================
#
# Procedure: cn_turnier_open
#
# Purpose: ffnen eines Turnieres 
#
# Preconditions:
#  Es darf kein Turnier geffnet sein. Das zu ffnende
#  Turnier muss vorhanden sein.
#
# Postconditions:
#  Gewuenschtes Turnier ist offen
#
# Returns: - keine -             
#
#=============================================================
                     
proc cn_turnier_open { } {

   # Prfen, ob Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {!$s} {
      ui_warning $Tname "Turnier darf nicht geffnet sein!"
      return
   }

   # Auflisten der vorhandenen Turniere und Auswahl eines Turniers
   set s [ui_turnier_list Tid Tname select]
   if {$s} {return}; # Fehler!

   # Holen der Runden
   set s [db_turnier_load $Tid Tname Spielnum Spielleiter runden mannschaften]
#   if {$s} {return}

   # Darstellen des Turnieres
   set s [ui_turnier_display $Tid $Tname $Spielnum Spielleiter runden mannschaften]
   if {$s} {return}
   
}     

#===========================================================
#
# Procedure: cn_turnier_close
#
# Purpose: Schlieen eines Turnieres 
#
# Preconditions:
#  Es mu ein Turnier geffnet sein. 
#
# Postconditions:
#  Geffnetes Turnier ist geschlossen.
#
# Returns: - keine -             
#
#=============================================================

proc cn_turnier_close { } {

   # Prfen, ob Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet, deshalb Schlieen nicht mglich!"
      return
   }

   # Schlieen des geffneten Turnieres
   set s [db_turnier_close $Tid]
   if {$s} {return}

   # Lschen der Anzeige
   set s [ui_turnier_clear] 
   return
   
}     

#===========================================================
#
# Procedure: cn_turnier_modify
#
# Purpose: ndern der Daten eines Turnieres 
#
# Preconditions:
#  Es mu ein Turnier geffnet sein. Das geffnete Turnier muss vorhanden sein.
#
# Postconditions:
#  Tname, Spielnum, Spielleiter sind gendert
#
# Returns: - keine -   
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Weiterreichen der Tid an das nderungsmodul zur Anzeige
#
#-------------------------------------------------------

proc cn_turnier_modify { } {

   # Prfen, ob Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }

   # Holen der allgemeinen Turnierdaten
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {$s} { return 1 }; # Fehler!

   # Anzeigen und ndern der Daten
   set s [ui_turnier_enter $Tid Tname Spielnum Spielleiter]
   if {$s} { return 1 }; #Fehler!

   # Sichern der Daten
   set s [db_Turnier_save $Tid $Tname $Spielnum Spielleiter]
   if {$s} { return 1}; # Fehler   
                         
   # Aktualisieren der Anzeige
   set s [ui_turnierdat_display $Tid $Tname $Spielnum Spielleiter]
   if {$s} { return 1}; # Fehler   
   return 0;

}     

#===========================================================
#
# Procedure: cn_turnier_overview
#
# Purpose:  bersicht ber die vorhandenen Turniere
#
# Preconditions:
#  keine
#
# Postconditions:
#  Es erscheint ein Window mit der Liste der vorhandenen Turniere
#
# Returns: - keine -
#
#=============================================================

proc cn_turnier_overview  { } {

   # Auflisten der vorhandenen Turniere ud Auswahl eines Turniers
   set s [ui_turnier_list Tid Tname display]
   return
}     

#===========================================================
#
# Procedure: cn_turnier_exit
#
# Purpose:  Beenden der Anwendung
#
# Preconditions:
#  Turnier kann geffnet sein
#
# Postconditions:
#  Falls Turnier geffnet, erscheint Frage, ob trotzdem weitermachen
#
# Returns: - keine -
#
#=============================================================

proc cn_turnier_exit { } {

   # Holen des geffneten Turnieres
   set s [db_Tid_get Tname Tid]
   if {$s} { exit } else {
      if { [YesNoBox "Turnier ist geffnet. Trotzdem beenden?" 300x50] != 0} {
         exit
      }
   }
 
   return
}     

#===========================================================
#
# Procedure: cn_turnier_add
#
# Purpose: Anlegen eines neuen Turnieres 
#
# Preconditions:
#  Es darf kein Turnier geffnet sein.
#
# Postconditions:
#  Neues Turnier ist angelegt
#
# Returns: - keine -
#
#=============================================================
#--------------------------------------------------------
# Changed:  4-OCT-1997
# Name: G.Niklaus
# Reason: Bug fixing - Bei ui_turnier_enter fehlte $Tid
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: Spielleiter(Siegpunkte) eingefuehrt
#
#-------------------------------------------------------

proc cn_turnier_add { } {

   # Prfen,, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {!$s} {
      ui_warning $Tname "Turnier darf nicht geffnet sein!"
      return 
   }

   # Eingeben der Daten des anzulegenden Turnieres
   set Spielnum 0
   set Spielleiter(Siegpunkte) "2"
   set Spielleiter(Name) ""
   set Spielleiter(Strasse) ""
   set Spielleiter(Wohnort) ""
   set Spielleiter(Telefon) ""
   set Spielleiter(FAX) ""
   set Spielleiter(Mail) ""
   set Spielleiter(globaltid) ""
   set Tname ""
   set s [ui_turnier_enter $Tid Tname Spielnum Spielleiter]
   if {$s} { 
      return
   }

   # Holen der nchstmglichen Tid
   set Tid 0
   set s [db_Tid_getnext Tid]
   if {$s} {
      ui_warning Fehler "Keine neue Tid mehr mglich"
      return
   }

   # Anlegen der neuen Directory
   set s [db_dir_create $Tid]
   if {$s} {
      ui_warning Fehler "Kein neues Turnierverzeichnis mehr mglich"
      return
   }

   # Speichern des neuen Turnieres
   set s [db_Turnier_save $Tid $Tname $Spielnum Spielleiter]
   if {$s} {
      ui_warning Fehler "Turnier konnte nicht gespeichert werden."
      return
   }

}

#===========================================================
#
# Procedure: cn_turnier_delete
#
# Purpose: Lschen eines Turnieres 
#
# Preconditions:
#  Es darf kein Turnier geffnet sein.
#
# Postconditions:
#  Ausgewhltes Turnier ist gelscht
#
# Globals: 
#  turdir
#  remodircmd
#
# Returns: - keine -
#
#=============================================================

proc cn_turnier_delete { } {
   # Globals
   global turdir
   global remodircmd

   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {!$s} {
      ui_warning $Tname "Turnier darf nicht geffnet sein!"
      return
   }

   # Auswhlen eines Turnieres
   set s [ui_turnier_list Tid Tname delete] 
   if {$s} { return }

   # Kontrollabfrage, ob Turnier richtig
   if { [YesNoBox "Turnier $Tname mit ID $Tid wirklich lschen?" 300x50] != 0 } {
      set curdir [pwd]
      cd $turdir
      set remodir [format $remodircmd $Tid]
      eval $remodir
   }
}
