#===========================================================
#
# Procedure: cn_mannschaft_add
#
# Purpose: Hinzufgen einer Mannschaft
#
# Preconditions:
#  Turnier mu geffnet sein. Es darf nicht ausgelost sein.
#  
#          
# Postconditions:
#  Name und Heimspieltag einer Mannschaft ist dem Turnier am Ende
#  hinzugefgt
#
# Returns: - keine -
#
#=============================================================
proc cn_mannschaft_add { } {
   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }
   # Eingabe und Speichern von Mannschaft und Heimspieltag
   set s [ui_mannschaft_enter "" "" "" "" add] 
}

#===========================================================
#
# Procedure: cn_mannschaft_modify
#
# Purpose: ndern einer Mannschaft
#
# Preconditions:
#  Turnier mu geffnet sein. Es darf ausgelost sein.
#  
# Postconditions:
#  Name und Heimspieltag einer Mannschaft wird angezeigt und auf einen
#  anderen Wert gendert.
#
# Returns: - keine -
#
#=============================================================
proc cn_mannschaft_modify { } {
   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }
   # Holen der selektierten Mannschaftsdaten 
   set s [ui_mannschaft_getsel Nr Mid Name Heimspieltag]
              
   if {$s} {
      ui_warning $Tname "Keine Mannschaft ausgewhlt."
      return
   }

   # Eingabe und Speichern von Mannschaft und Heimspieltag
   set s [ui_mannschaft_enter $Nr $Mid $Name $Heimspieltag modify] 
}

#===========================================================
#
# Procedure: cn_mannschaft_delete
#
# Purpose: Loeschen einer Mannschaft
#
# Preconditions:
#  Turnier mu geffnet sein. Es darf nicht ausgelost sein.
#  
# Postconditions:
#  Eine Mannschaft ist nach Rckfrage gelscht worden.
#
# Returns: - keine -
#
#=============================================================
proc cn_mannschaft_delete { } {
   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }
   # Holen der selektierten Mannschaftsdaten 
   set s [ui_mannschaft_getsel Nr Mid Name Heimspieltag]
   if {$s} {
      ui_warning $Tname "Keine Mannschaft ausgewhlt."
      return
   }

   # Abfrage, ob Mannschaft tatschlich gelscht werden soll
   if {[YesNoBox "Mannschaft $Name lschen?" 300x50] != 0} {
      set s [db_mannschaft_del $Tid $Nr]
      set s [db_mannschaft_selall $Tid mannschaften]
      set s [ui_mannschaft_display mannschaften]
   }
}

#===========================================================
#
# Procedure: cn_mannschaft_exchange
#
# Purpose: Tauschen einer Mannschaft mit einer anderen.
#
# Preconditions:
#  Turnier mu geffnet sein. Es darf nicht ausgelost sein.
#  
# Postconditions:
#  Zwei Mannschaft sind in der Reihenfolge getauscht worden
#
# Returns: - keine -
#
#=============================================================
proc cn_mannschaft_exchange { } {
   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }
   # Holen der selektierten Mannschaftsdaten 
   set s [ui_mannschaft_exchange]
   set s [db_mannschaft_selall $Tid mannschaften]
   set s [ui_mannschaft_display mannschaften]
}

#===========================================================
#
# Procedure: cn_mannschaft_meldung
#
# Purpose: Eingabe, ndern einer Mannschaftsmeldung
#
# Preconditions:
#  Turnier mu geffnet sein. Es darf ausgelost sein.
#  Die entsprechende Mannschaft mu selektiert sein.
#
# Postconditions:
#  Die Mannschaftsmeldung ist angezeigt und u.U gendert worden.
#
# Returns: - keine -
#
#=============================================================
proc cn_mannschaft_meldung { } {
   # Prfen, ob ein Turnier geffnet ist
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Turnier mu geffnet sein!"
      return
   }
   # Holen der selektierten Mannschaftsdaten 
   set s [ui_mannschaft_getsel Nr Mid Name Heimspieltag]
   if {$s} {
      ui_warning $Tname "Keine Mannschaft ausgewhlt."
      return
   }

   # Anzeige, ndern der Mannschaftsmeldung
   set s [ui_meldung_enter $Tid $Mid $Name]
}

#============================================================
#
# Procedure: cn_mannschaft_save
#
# Purpose: Speichern einer Mannschaft
#
# Preconditions:
#  In den globalen Variablen 
#        G_Nr, G_Mid, G_Name und G_Heimspieltag
#  stehen die Daten der betreffenden Mannschaft. Der Parameter func 
#  sagt aus, ob #  eine Mannschaft gendert oder eine neue hinzugefgt 
#  werden mu.
#
# Postconditions:
#  Die entsprechende Mannschaft ist gendert bzw. hinzugefgt und auf
#  Platte gespeichert.
#
# Globals:
#  G_Nr              
#  G_Mid
#  G_Name
#  G_Heimspieltag
#
# Returns: - keine-
#
#=============================================================
proc cn_mannschaft_save { func } {
   # Globals
   global G_Nr
   global G_Mid
   global G_Name
   global G_Heimspieltag

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]


   # ndern oder Speichern der Mannschaft
   if { [string compare $func "modify"] == 0 } {
      set s [db_mannschaft_modify $Tid $G_Nr $G_Mid $G_Name $G_Heimspieltag]
   } else {
      set s [db_Mid_getnext $Tid Mid]
      set s [db_mannschaft_add $Tid $Mid $G_Name $G_Heimspieltag]
   }
   
   # Holen der vorhandenen Mannschaften in ein Array
   set s [db_mannschaft_selall $Tid mannschaften]
   
   # Laden der vorhandenen Mannschaften in das UI
   set s [ui_mannschaft_display mannschaften]
}


