#============================================================
#
# Procedure: cn_mannschaft_tauschen
#
# Purpose: Tauschen einer Mannschaft
#
# Preconditions:
#  In den globalen Variablen 
#        G_Nr1, G_Nr2 
#  stehen die Nummern der betreffenden Mannschaft. 
#
# Postconditions:
#  Die betreffenden Mannschaften sind getauscht worden.
#
# Globals:
#  G_Nr1
#  G_Nr2
#
# Returns: - keine-
#
#=============================================================
proc cn_mannschaft_tauschen { } {
   # Globals
   global G_Nr1
   global G_Nr2

   # Holen der aktuellen Turnierdaten
   set s [db_Tid_get Tname Tid]
   
   # Holen der vorhandenen Mannschaften in ein Array
   set s [db_mannschaft_selall $Tid mannschaften]

   # Vertauschen
   set hilf $mannschaften($G_Nr1)
   set mannschaften($G_Nr1) $mannschaften($G_Nr2)
   set mannschaften($G_Nr2) $hilf
   
   # Speichern der getauschten Mannschaften 
   set s [db_mannschaft_store $Tid mannschaften]
   
   # Laden der vorhandenen Mannschaften in das UI
   set s [ui_mannschaft_display mannschaften]
}

#===========================================================
#
# Procedure: cn_runde_modify
#
# Purpose: ndern des Austragungsdatums einer Runde
#
# Preconditions:
#  Turnier mu geffnet sein. Eine Runde mu selektiert sein.
#
# Postconditions:
#  Datum der selektierten Runde ist gendert.
#
# Returns: - keine -
#
#=============================================================
                            
proc cn_runde_modify { } {

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Holen der selektierten Runde  
   set Runde ""; set Rundendatum ""; set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Darstellen der Werte und eventuelles ndern
   set s [ui_runde_enter $Runde $Rundendatum modify]

}

#===========================================================
#
# Procedure: cn_runde_add
#
# Purpose: Eingabe des Datums einer neuen Runde
#
# Preconditions:
#  Turnier mu geffnet sein. 
#
# Postconditions:
#  Datum der neune Runde ist eingegeben.
#
# Returns: - keine -
#
#=============================================================

proc cn_runde_add { } {

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Keine Turnier geffnet."
      return
   }

   # Darstellen der Werte und eventuelles ndern
   set s [ui_runde_enter "" "" add]
}

#============================================================
#
# Procedure: cn_runde_save
#
# Purpose: Speichern einer Runde
#
# Preconditions:
#  In den globalen Variablen G_Runde und G_Rundendatum stehen die
#  Daten der betreffenden Runde. Der Parameter func sagt aus, ob
#  eine Runde gendert oder eine neue hinzugefgt werden mu
#
# Postconditions:
#  Die entsprechende Runde ist gendert bzw. hinzugefgt und auf
#  Platte gespeichert.
#
# Globals:
#  G_Runde
#  G_Rundendatum
#
#=============================================================

proc cn_runde_save { func } {
   # Globals
   global G_Runde 
   global G_Rundendatum
   
   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   
   # ndern oder Speichern der Runde
   if { [string compare $func "modify"] == 0 } {
      set s [db_runde_modify $Tid $G_Runde $G_Rundendatum]
   } else {
      set s [db_runde_add $Tid $G_Rundendatum]
   }
   
   # Holen der vorhandenen Runden in ein Array
   set s [db_runde_selall $Tid runden]
   
   # Laden der vorhandenen Runden in das UI
   set s [ui_runde_display runden]

}

#===========================================================
#
# Procedure: cn_runde_del
#
# Purpose: Lschen einer angewhlten Runde
#
# Preconditions:
#  Turnier mu geffnet sein. Runde mu angewhlt sein
#
# Postconditions:
#  Runde ist gelscht.
#
# Returns: - keine -
#
#=============================================================

proc cn_runde_del { } {

   # Holen der aktuellen Turnierdaten
   set Tname ""; set Tid ""; set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Holen der selektierten Runde  
   set Runde ""; set Rundendatum ""; set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }             

   # Abfrage, ob Runde tatschlich gelscht werden soll
   if {[YesNoBox "Runde $Runde lschen?" 300x50] != 0} {
      set s [db_runde_del $Tid $Runde]
      set s [db_runde_selall $Tid runden]
      set s [ui_runde_display runden]
   }
}        

#===========================================================
#
# Procedure: cn_turnier_move
#
# Purpose: Umspeichern der allgemeinen Turnierdaten aus den
#          Globals in bergabeparameter
#
# Preconditions:
#  Werte sind in den Globals l* vorhanden
#
# Postconditions:
#  Werte sind in die bergabeparameter gespeichert.
#
# Returns: 0 = success
#
#=============================================================

#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung, entspr. globale Variable
#
#-------------------------------------------------------
proc cn_turnier_move { VarTname VarSpielnum ArraySpielleiter } {
   # Pseudoglobals, notwendig, um die Eingabefelder der Maske
   # abzufragen.
   global lTname 
   global lSpielnum 
   global lsiegpunkte
   global lname 
   global lstr  
   global lwohn 
   global ltele 
   global lfax  
   global lmail 
   global lglobaltid
   global lretval

   upvar $VarTname Tname
   upvar $VarSpielnum Spielnum
   upvar $ArraySpielleiter Spielleiter

   set Tname $lTname 
   set Spielnum $lSpielnum 
   set Spielleiter(Siegpunkte) $lsiegpunkte
   set Spielleiter(Name) $lname 
   set Spielleiter(Strasse) $lstr  
   set Spielleiter(Wohnort) $lwohn 
   set Spielleiter(Telefon) $ltele 
   set Spielleiter(FAX) $lfax  
   set Spielleiter(Mail) $lmail 
   set Spielleiter(globaltid) $lglobaltid

   return 0
}        

#===========================================================
#
# Procedure: cn_spiel_auslosung
#
# Purpose: Festlegen des Spielplans des Turnieres, Auslosung
#
# Preconditions:
#  Mannschaften sind eingegeben.
#
# Postconditions:
#  Die Paarungen werden anhand der Turniertabellen bestimmt.
#  Die Daten werden pro Runde in eine Datei gespeichert
#  Name : r.<runde>
#  Format: heim gast Spielflag HBrettPkt HMannPkt ABrettpkt AMannPkt
#  Wenn Heim oder Gast = 0, dann spielfrei.
#
# Returns: 0 = success
#
#=============================================================

proc cn_spiel_auslosung { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {!$s} {
      ui_warning $Tname "Turnier ist schon ausgelost."
      return
   }

   # Vornehmen der Auslosung
   set s [cn_auslosung $Tid]

   # Markieren der Auslosung
   set s [db_auslos_set $Tid 1]
   return
}

#===========================================================
#
# Procedure: cn_spiel_auslosung_storno               
#
# Purpose: Aufheben der Auslosung
#
# Preconditions:
#  Mannschaften sind eingegeben. Turnier ist geffnet
#
# Postconditions:
#  Die Auslosung ist zurckgesetzt.
#
# Returns: 0 = success
#
#=============================================================

proc cn_spiel_auslosung_storno { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, Aufhebung nicht notwendig."
      return
   }

   # Nachfragen!
   if { [YesNoBox "Turnierauslosung wirklich zurcknehmen? " 300x50] != 0} {
      # Markieren der Auslosung
      set s [db_auslos_set $Tid 0]
   }
   return
}

