#===========================================================
#
# Procedure: cn_releasenotes
#
# Purpose: Darstellen der Releasenotes
#
# Preconditions:
#  Datei der Releasenotes muss existieren
#  Datei muss sich im Default Directory befinden!
#
# Postconditions:       
#  Release Notes werden angezeigt.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_releasenotes { } {
global sh_dir

   set relnotesfile "$sh_dir/release.txt"
   # Holen Releasenotes
   set s [db_releasenotes_selall $relnotesfile Releasenotes]

   # Anzeige der Releasenotes
   set s [ui_releasenotes_display $Releasenotes]
   return 0
}
#===========================================================
#
# Procedure: cn_usersguide
#
# Purpose: Darstellen der Users Guide
#
# Preconditions:
#  Datei des Users Guide (user.txt) muss existieren
#  Datei muss sich im Scriptdirectoriy befinden!
#
# Postconditions:       
#  Users Guide wird angezeigt.
#
# Globals
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 28-MAY-1997
# Name: G.Niklaus
# Reason: Angelegt
#
#-------------------------------------------------------
     
proc cn_usersguide { } {
global sh_dir

   set usersguide "$sh_dir/user.txt"
   # Holen des Users Guide
   set s [db_usersguide_selall $usersguide Guide]

   # Anzeige des Users Guide
   set s [ui_usersguide_display $Guide]
   return 0
}

#===========================================================
#
# Procedure: cn_spielplan_anhang_display
#
# Purpose: Generieren und Anzeigen des Anhanges fr den Spielplan.
#
# Preconditions:
#  Turnier ist geffnet
#
# Postconditions:
#  Der Anhang fr den Spielplan ist erstellt und gespeichert.
#
# Returns: 0 = success
#
#=============================================================

proc cn_spielplan_anhang_display { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Erstellen des Anhanges des Spielplanes in eine Datei
   set s [ui_spielplan_anhang_enter $Tid]
   return
}

#===========================================================
#
# Procedure: cn_rundenbericht_anhang
#
# Purpose: Erstellen eines Anhangs zu einem Rundenbericht
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Fr diese Runde wird der Anhang erstellt.
#
# Postconditions:       
#  Rundenanhang ist erstellt wordem, in Datei gespeichert und in
#  Fenster angezeigt worden.
#
# Globals
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Creation
#
#-------------------------------------------------------
                                                                 
proc cn_rundenbericht_anhang { } {

   # Holen Turnierdaten 
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Eingabe mglich."
      return
   }

   # Holen der selektierten Runde  
   set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Darstellen/ndern des Anhanges zur Runde
   set s [ui_rundenbericht_anhang_enter $Tid $Runde ]

   return 0

}

#===========================================================
#
# Procedure: cn_turnier_export
#
# Purpose: Exportieren der Daten eines Turnieres
#
# Preconditions:                          
#  Es darf kein Turnier geffnet sein.
#
# Postconditions:       
#  Ein ausgewhltes Turnier ist exportiert worden. Alle Daten wurden
#  in eine ZIP-Datei gepackt und im Export-Verzeichnis bereitgestellt.
#
# Globals
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Creation
#
#-------------------------------------------------------
                                                                 
proc cn_turnier_export { } {

   # Holen Turnierdaten 
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {!$s} {
      ui_warning $Tname "Fr den Export darf kein Turnier geffnet."
      return
   }

   set Tid ""   
   # Auflisten der vorhandenen Turniere ud Auswahl eines Turniers
   set s [ui_turnier_list Tid Tname export]

   return 0

}

