#============================================================
#
# Procedure: db_runde_del
#
# Purpose: Loeschen einer Runde 
#
# Preconditions: Parameter Tid enthlt das jeweilige Turnier
#     Parameter Runde enthlt die Nummer der zu lschenden Runde
#
# Postconditions:
#   Aktualisierte Rundenspieltermine sind in Datei $turdir/$Tid/runden.txt 
#   geschrieben.
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_runde_del { Tid Runde } {                                  

   # Laden der vorhandenen Runden
   set s [db_runde_selall $Tid runden]
   if {$s} { return 1}

   # Lschen der Runde
   unset runden($Runde)
   # Speichern der verbleibenden Runden
   set s [db_runde_store $Tid runden]
   if {$s} { return 1}
   return 0
}


#============================================================
#
# Procedure: db_mannschaft_add
#
# Purpose: Hinzufgen einer neuen Mannschaft
#              
# Preconditions: Turnier mu geffnet sein.
#
# Postconditions:
#   Die Mannschaften werden gelesen, gendert und neu in Datei geschrieben
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler    
#=============================================================

proc db_mannschaft_add { Tid Mid Name Heimspieltag } {

   set s [db_mannschaft_selall $Tid mannschaften]
   if { [info exists mannschaften] } {
      set i [lindex [lsort -integer -decreasing [array names mannschaften] ] 0 ]
      incr i
   } else {
      set i 1
   }
   set mannschaften($i) [list $Mid  $Name $Heimspieltag]
   set s [db_mannschaft_store $Tid mannschaften]
   return $s
}

#============================================================
#
# Procedure: db_mannschaft_modify
#
# Purpose: ndern der Daten einer Mannschaft
#
# Preconditions: Tid mu ein gltiges Turnier enthalten
#   Nr mu auf eine gltige Mannschaft zeigen.
#
# Postconditions:
#   Die angegebene Mannschaft wird durch die erhaltenen Daten berschrieben.
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_mannschaft_modify { Tid Nr Mid Name Heimspieltag } {

   # Holen der bekannten Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]
   if {$s} { return 1}

   # ndern der Mannschaft
   set mannschaften($Nr) [list $Mid  $Name $Heimspieltag]

   # Speichern der neuen Daten
   set s [db_mannschaft_store $Tid mannschaften]
   if {$s} {return 1}
   return 0
}                      
          
#============================================================
#
# Procedure: db_mannschaft_del
#
# Purpose: Lschen einer Mannschaft
#
# Preconditions: Parameter Tid enthlt das jeweilige Turnier
#     Parameter Nr enthlt die Nummer der zu lschenden Mannschaft
#
# Postconditions:
#   Aktualisierte Mannschaften sind in Datei $turdir/$Tid/$mannschfile
#   geschrieben.
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  5-MAY-1997
# Name: G.Niklaus
# Reason: Wegloeschen nicht mehr gebrauchter Files
#
#-------------------------------------------------------

proc db_mannschaft_del { Tid Nr } {                                  
   global turdir
   global remofilcmd

   # Laden der vorhandenen Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]
   if {$s} { return 1}

   set curdir [pwd]
   cd $turdir/$Tid
   set meldnr [lindex $mannschaften($Nr) 0]
   set remofil [format $remofilcmd $meldnr]
   eval $remofil
   cd $curdir

   # Lschen der Mannschaft
   unset mannschaften($Nr)
   # Speichern der verbleibenden Mannschaften
   set s [db_mannschaft_store $Tid mannschaften]
   if {$s} { return 1}
   return 0
}
#============================================================
#
# Procedure: db_mannschaft_store 
#
# Purpose: Speichern der Mannschaftsdaten
#
# Preconditions: Turnier mu geffnet sein.
#     
#
# Postconditions:
#   Mannschaften sind in Datei $turdir/$Tid/$mannschfile geschrieben.
#
# Globals:
#   mannschfile
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_mannschaft_store { Tid Arraymannschaften } {
   # Globals
   global turdir
   global mannschfile

   upvar $Arraymannschaften mannschaften

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set f [open $mannschfile w]
   set ilist [lsort -integer [array names mannschaften] ]
   foreach i $ilist {
      puts $f $mannschaften($i)
   }
   close $f
   cd $curdir
   return 0
}
#============================================================
#
# Procedure: db_meldung_selall
#
# Purpose: Holen der Mannschaftsmeldung
#
# Preconditions: Turnier mu geffnet sein.
#     Tid zeigt auf das geffnete Turnier
#     Mid zeigt auf die Mannschaftsmeldung
#
# Postconditions:
#   Mannschaftsmeldung wird auf Datei $turdir/$Tid/$Mid gelesen.
#
# Globals:
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Rckgabe des Dateinamens der Mannschaftsmeldung
#
#-------------------------------------------------------

proc db_meldung_selall { Tid Mid Varmeldung Vardateiname} {
   # Globals
   global turdir

   upvar $Varmeldung meldung
   upvar $Vardateiname dateiname

   set dateiname $turdir/$Tid/$Mid;
   set curdir [pwd]
   cd $turdir
   cd $Tid      

   if { [file exists $Mid] == 1 } {
      set f [open $Mid r]
      set meldung [read -nonewline $f]
      close $f
      cd $curdir
      return 0
   }
   cd $curdir
   return 1
}

#============================================================
#
# Procedure: db_meldung_store 
#
# Purpose: Speichern der Mannschaftsmeldung
#
# Preconditions: Turnier mu geffnet sein.
#     Tid zeigt auf das geffnete Turnier
#     Mid zeigt auf die Mannschaftsmeldung
#
# Postconditions:
#   Mannschaftsmeldung wird sind in Datei $turdir/$Tid/$Mid geschrieben.
#
# Globals:
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_meldung_store { Tid Mid } {
   # Globals
   global turdir
   global page_color

   set w .ui_meldung_enter

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set meldung [$w.text get 0.0 end]
   set f [open $Mid w]
   puts -nonewline $f $meldung
   close $f

#--------------------------------------------------------
# Changed: 25-JUL-1999
# Name: G.Niklaus
# Reason: Anlegen des HTML-Files
#
#-------------------------------------------------------
   set f1 [open $Mid.htm w]
   puts $f1 "<html>"
   puts $f1 $page_color
   puts $f1 "<pre>"
   puts -nonewline $f1 $meldung
   puts $f1 "</pre>"
   puts $f1 "</html>"
   close $f1

   cd $curdir
   return 0
}
                                     
#============================================================
#
# Procedure: db_mannschaft_selall
#
# Purpose: Holen der Mannschaften des Turnieres
#
# Preconditions: Turnier mu geffnet sein.
#   
# Postconditions:
#   Mannschaften in Array geholt.
#
# Globals:
#   mannschfile : Name des Mannschaftsfiles
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_mannschaft_selall { Tid Varmannschaften } {
   # Globals
   global turdir; # Directory der Turniere
   global mannschfile
       
   upvar $Varmannschaften mannschaften

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set s [catch {set f [open $mannschfile r]} ]
   if {$s} {cd $curdir; return 1}

   set i 0
   set zeile [gets $f]
   while { ![eof $f] } {
      incr i       
      set mannschaften($i) $zeile
      set zeile [gets $f]
   }
   close $f
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_runde_load
#
# Purpose: Laden der Wettkmpfe einer Runde
#
# Preconditions: Turnier mu geffnet sein.
#   Auslosung mu durchgefhrt sein. Tid und Runde mssen einen
#   gltigen Wert besitzen,
# 
# Postconditions:
#  Alle Wettkmpfe der Runde sind geladen
#
# Globals:
#   turdir
#   wettkampffile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_runde_load { Tid Runde Arraywettkampf } {
   # Globals
   global turdir
   global wettkampffile

   upvar $Arraywettkampf wettkampf

   set curdir [pwd]

   cd $turdir
   cd $Tid

   set i 0
   set fa [open $wettkampffile.$Runde r]
   gets $fa zeile
   while {![eof $fa]} {
      incr i           
      set wettkampf($i) $zeile
      gets $fa zeile
   }
   close $fa
   cd $curdir
   return 0

}
