#--------------------------------------------------------
# Changed: 23-JUL-1999
# Name: G.Niklaus
# Reason: Einbau neues Webseitenlayout
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 25-JUL-1999
# Name: G.Niklaus
# Reason: Zum Posten ins Internet alle Seiten verwenden, wie beim
#         Export
#         Wegloeschen der FTP-Prozedur
#-------------------------------------------------------

#============================================================
#
# Procedure: db_mannschaftname_selall
#              
# Purpose: Laden der Mannschaftsnamen aus Datei
#
# Preconditions:
#  Tid muss gueltigen Wert besitzen
# 
# Postconditions:
#  Namen der Mannschaften des Turniers Tid werden in Array zurueckgeliefert
#                      
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_mannschaftname_selall { Tid Varmannschaftname } {
   upvar $Varmannschaftname mannschaftname 

   set s [db_mannschaft_selall $Tid mannschaften]

   foreach k [lsort -integer [array names mannschaften]] {
      set mannschaftname($k) [lindex $mannschaften($k) 1]
   }
   return 0
}
#===========================================================
#
# Procedure: db_create_zip
#
# Purpose: Anlegen des ZIP-Files
#
# Preconditions:
#  Turnier muss gueltig sein
#  Runde muss gueltig sein
#  Dateiname wird geliefert
#
# Postconditions:       
#  Die fuer das Internet wichtigen Daten sind in das ZIP-File
#  geschrieben worden.
#
# Globals           
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 27-FEB-1999
# Name: G.Niklaus
# Reason: Der Dateiname wird von ober her uebergeben.
#         Das Zipfile wird zweimal angelegt.
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  4-MAR-1999
# Name: G.Niklaus
# Reason: Einfuegen der Mannschaftsauswertungen
#
#-------------------------------------------------------
                            
proc db_create_zip { Tid Runde Varzipfile } {
   global turdir
   global zip
   global indexfile
#  global datumcmd
   global spielplanfile
   global rundenbericht
   global mannschaftsbilanz
   global exportcmd
   upvar $Varzipfile zipfile

   set curdir [pwd]
   cd $turdir
   cd $Tid          
   
#  set datum [eval $datumcmd]
                      
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set zipname $Spielleiter(globaltid)
   set zipname $turdir/$Tid/$zipname.zip

   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   foreach k [array names mannschaften] {
      lappend mids [lindex $mannschaften($k) 0]
   }

   file delete -force $zipname
   file delete -force $zipfile
   set  export2 [format $exportcmd $zipfile]
   set  export1 [format $exportcmd $zipname]
   catch { eval "exec $export2" }
   catch { eval "exec $export1" }

   cd $curdir
   return 0
}

#===========================================================
#      
# Procedure: db_create_www
#
# Purpose: Anlegen der WWW-Seiten
#
# Preconditions:
#  Turnier muss gueltig sein
#  Runde muss gueltig sein
#
# Postconditions:       
#  Im Directory des Turnieres ist Datei index.htm 
#  angelegt worden.
#
# Globals           
#   turdir                               
#   zip
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed: 31-AUG-1998
# Name: G.Niklaus
# Reason: Change of Layout of Webpages
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  4-MAR-1999
# Name: G.Niklaus
# Reason: Einfuegen der Mannschaftsauswertungen
#
#-------------------------------------------------------
                            
proc db_create_www { Tid Tname Runde } {
   global turdir
   global zip
   global indexfile
   global page_color
   global logo1
   global logo2
   global alt_logo1
   global alt_logo2
   global datumcmd
#   global spielplanfile
   global spielplanhtm
   global rundenbericht
   global mannschaftsbilanz
   global bg_image

   set curdir [pwd]
   cd $turdir
   cd $Tid
       
   set datum [eval $datumcmd]

   set s [db_turnier_get Tid Tname Spielnum Spielleiter]

   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]
   set s [db_runde_selall $Tid runden]           

   set f1 [open $indexfile w]

   # HTML-Kopf schreiben
   puts $f1 "<HTML><HEAD><TITLE> $Tname</TITLE>"
   puts $f1 "<META NAME=\"GENERATOR\" CONTENT=\"TCL/TK TKTUR\">"
   puts $f1 "</HEAD>"

   # Der Seitenkopf
   puts $f1 $page_color
   puts $f1 "<H1>$Tname</H1>"
                                         
   # Angaben zum Spielleiter
   puts $f1 "<P><FONT SIZE=+1><B>Spielleiter:<BR></B>"
   puts $f1 "$Spielleiter(Name)<BR>$Spielleiter(Strasse)<BR>$Spielleiter(Wohnort)<BR>"
   puts $f1 "Telefon: $Spielleiter(Telefon)<BR>FAX: $Spielleiter(FAX)<BR>Mail: $Spielleiter(Mail)<BR>"

   # Der allgemeine Teil
   puts $f1 "<HR> <h3>Der <A HREF=\"$spielplanhtm\">Spielplan</A></h3></font></P>"
   puts $f1 "<P><FONT SIZE=+1>Der derzeitige Stand des Turnieres als <A HREF=\"$Spielleiter(globaltid).zip\">"
   puts $f1 "Zip-Datei (40 kB)</A>.</FONT></P>"
#   puts $f1 "<HR>"
   puts $f1 "<p><h3>Die <a href=\"$mannschaftsbilanz.htm\">Spielerbilanzen</a></h3>"

   puts $f1 "<P>"
   puts $f1 "<HR SIZE=3 NOSHADE WIDTH=\"100%\"></P>"

   # Die Turnierinformationen - Mannschaften
   puts $f1 "<TABLE BORDER=1 CELLPADDING=5 ><TR>"
   puts $f1 "<TD><B>Teilnehmende Mannschaften</B></TD>"
#   puts $f1 "<TH>Mailadresse</TH>"
   puts $f1 "<TD><B>Runden + Termine</B></TD></TR>"
   puts $f1 "<TR><TD><OL>"
   foreach k [lsort -integer [array names mannschaften]] {
      set mannschaftname [lindex $mannschaften($k) 1]
      set Mid [lindex $mannschaften($k) 0]
      puts $f1 "<LI><A HREF=\"$Mid.htm\">$mannschaftname</A></LI>"
   } 
   puts $f1 "</OL></TD>"
                 
   # Die Turnierinformationen - Termine
   puts $f1 "<TD valign=top>"
   foreach k [lsort -integer [array names runden]] {
      set html_string($k) "$k: $runden($k)<BR>"
   }
   for { set k 0 } { $k < $Runde } { incr k } {
      set j [expr $k+1]
      set html_string($j) "$j: <A HREF=\"$rundenbericht$j.htm\">$runden($j)</A><BR>"
   }
   foreach k [lsort -integer [array names html_string]] {
      puts $f1 $html_string($k)
   }                               
   puts $f1 "</TD></TR></TABLE>"


   # Der Seiten-Trailer
   puts $f1 "<div align=\"right\">"
   puts $f1 "<p align=\"right\"><em><FONT SIZE=-1>&copy; Schachkreis Mittelfranken-Nord<BR>"
   puts $f1 "Letzte &Auml;nderung: $datum<BR><SCRIPT language=\"JavaScript\">"
   puts $f1 "<!--"
   puts $f1 "document.write(\"URL: \"+document.location.href);"
   puts $f1 "//-->"     
   puts $f1 "</SCRIPT>"
   puts $f1 "<BR>$Spielleiter(Name)</FONT></I></em>"
   puts $f1 "</div>"
   puts $f1 "</BODY>"
   puts $f1 "</HTML>"

   close $f1             
   cd $curdir
   return 0
}

#===========================================================
#
# Procedure: db_mannschaftsbilanz_store 
#
# Purpose: Speichern der Auswertung einer Mannschaft
#
# Preconditions:                          
#  Turnier mu geffnet sein.
#  Datenstruktur Rangliste(name) mu gefllt sein:
#    name:  100*mannschaftsnummer + brettnummer
#    Element 0:  Brettnummer
#    Element 1:  Name+Vorname
#    Element 2:  Vereinsnummer
#    Element 3:  Punkte
#    Element 4:  Spiele
#    Element 5:  String der Ergebnisse
#
# Postconditions:       
#  Es werden Files $mannschafts$mid.htm im Turnierdirectory angelegt.
#  
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed:   4-MAR-1999
# Name: G.Niklaus
# Reason: Speichern der Mannschaftsauswertungen
#
#-------------------------------------------------------

proc db_mannschaftsbilanz_store { Tid Tname Runde ArrayRangliste } {
global turdir
global mannschaftsbilanz
#global bg_image
global datumcmd
global page_color
        
   upvar $ArrayRangliste Rangliste
                            
   set curdir [pwd]
   cd $turdir/$Tid

   set datum [eval $datumcmd]

   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set s [db_mannschaft_selall $Tid mannschaften]
   set RundenAnzahl [array size mannschaften]
   if { ($RundenAnzahl & 1) != 1 } { incr RundenAnzahl -1 }
   for { set i 1 } { $i <= $RundenAnzahl } { incr i } {
      set lv [string length $i]
      set v [string range $i [expr $lv-1] end]
      append s3 "-"
      append rdstring "$v"
   }                                

#foreach k [lsort -integer [array names Rangliste]] {
#   puts "$k : |[lindex $Rangliste($k) 5]|"
#}                                      
#foreach k [lsort -integer [array names mannschaften]] {
#    puts "$k : |$mannschaften($k)|"
#}                      
      set f5 [open $mannschaftsbilanz.htm w]
      # HTML-Kopf schreiben
      puts $f5 "<HTML><HEAD><TITLE> $Tname</TITLE>"
      puts $f5 "<META NAME=\"GENERATOR\" CONTENT=\"TCL/TK TKTUR\">"
      puts $f5 "</HEAD>"
   
      # Der Seitenkopf
      puts $f5 $page_color
      puts $f5 "<H1>$Tname</H1>"
      # Angaben zum Spielleiter
      puts $f5 "<P><FONT SIZE=+1><B>Spielleiter:<BR></B>"
      puts $f5 "$Spielleiter(Name)<BR>$Spielleiter(Strasse)<BR>$Spielleiter(Wohnort)<BR>"
      puts $f5 "Telefon: $Spielleiter(Telefon)<BR>FAX: $Spielleiter(FAX)<BR>Mail: $Spielleiter(Mail)<BR>"
      puts $f5 "<pre>"                            

      set s1 "------------------------+"
      set s2 "+----------"
      append s2string $s1 $s3 $s2
      set s1string [format "%2s %-20s |%s| Pkt. Erf." {Br} {Name} $rdstring ]

   foreach k [array names mannschaften] {
      set Mid [lindex $mannschaften($k) 0]
      set Verein [lindex $mannschaften($k) 1]
#     puts "-------------\nk = $k, Mid = $Mid, Verein = $Verein"
#     set f5 [open $mannschaftsbilanz$Mid.htm w]
      puts $f5 "<hr size=4 noshade>"
      puts $f5 "Bilanz $Verein\n"
      puts $f5 $s1string
      puts $f5 $s2string
      foreach spieler [lsort -integer [array names Rangliste $k??]] {
         set brettnr [lindex $Rangliste($spieler) 0]
         set name    [string range [lindex $Rangliste($spieler) 1] 0 19]
         set punkte  [lindex $Rangliste($spieler) 3]
         set spiele  [lindex $Rangliste($spieler) 4]
         set bilanz  [string range [lindex $Rangliste($spieler) 5] 1 end]
         set erfolg " "
         if { $spiele > 0 } {
            set erfolg  [expr int(1.0*$punkte/$spiele*100.0)]
         }
#        puts "Spieler = $spieler" 
#        puts "Name    = $name"
#        puts "Brettnr = $brettnr"
         set mystring [format "%02d %-20s |%s| %4s %3s" $brettnr $name $bilanz $punkte $erfolg]
         puts $f5 $mystring
      }                                              

   }
      puts $f5 "</pre>"
      # Der Seiten-Trailer
      puts $f5 "<div align=\"right\">"
      puts $f5 "<p align=\"right\"><em><FONT SIZE=-1>&copy; Schachkreis Mittelfranken-Nord<BR>"
      puts $f5 "<SCRIPT language=\"JavaScript\">"
      puts $f5 "<!--"                     
      puts $f5 "document.write(\"Letzte &Auml;nderung: \"+document.lastModified+\"<br>\");"
      puts $f5 "document.write(\"URL: \"+document.location.href);"
      puts $f5 "//-->"
      puts $f5 "</SCRIPT>"
      puts $f5 "<br>$Spielleiter(Name)</FONT></I></em>"
      puts $f5 "</div>"
      puts $f5 "</BODY>"
      puts $f5 "</HTML>"
      close $f5

   cd $curdir
   return 0
}
