#============================================================
#
# Procedure: ui_meldung_enter
#
# Purpose: Anzeige/Eingabe der Meldung einer Mannschaft
#
# Preconditions: 
#  Turnier mu geffnet sein. Mid enthlt die MannschaftsId, Name den
#  Namen der Mannschaft.
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die Meldung wird im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Anzeigen des Dateinamens der Mannschaftsmeldung
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  9-JUN-1998
# Name: G.Niklaus
# Reason: Anzeige der Kreuztabelle
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Einbau der tk_getOpenFile
#         Verkleinern des Windows der Mannschaftsmeldung
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Einfuegen der Buttons saveas und include
#
#-------------------------------------------------------

proc ui_meldung_enter { Tid Mid Name } {
global meldung

   set meldung ""
   # Holen der Mannschaftsmeldung
   set s [db_meldung_selall $Tid $Mid meldung dateiname]
   if {$s} {
      set meldung ""
      set Titel "Neue Meldung fr $Name : $dateiname"
   } else {
      set Titel "Meldung fr $Name: $dateiname"
   }

   # Aufbau des UIs
   set w .ui_meldung_enter
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "db_meldung_store $Tid $Mid; destroy $w"
   button $w.buttons.saveas -text "Speichern unter" -command "ui_meldung_save_file"
   button $w.buttons.include -text "File einfgen" -command "ui_meldung_open_file"
   button $w.buttons.cancel -text "Abbrechen" -command "destroy $w"
   pack $w.buttons.save $w.buttons.saveas $w.buttons.include $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 30 -width 80
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung der Mannschaftsmeldung
   $w.text insert end $meldung
}

#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Neue Funktion, Rufen der File Selection Box
#
#-------------------------------------------------------
proc ui_meldung_open_file {  } {
global meldung
global env
   set meldung ""
   set w .ui_meldung_enter
   set home $env(HOME)
   set filename [tk_getOpenFile -parent . -initialdir $home ]
   if { [string compare $filename ""] } {
      if { [ file exists $filename] == 1 } {
         set f [open $filename r]
         set meldung [read -nonewline $f]
         close $f
         $w.text delete 0.0 end     
         $w.text insert 0.0 $meldung
      }
   }
}

#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Neue Funktion, Rufen der File Selection Box
#
#-------------------------------------------------------
proc ui_meldung_save_file {  } {
global meldung
global env
   set w .ui_meldung_enter
   set meldung [$w.text get 0.0 end]
   set home $env(HOME)
   set filename [tk_getSaveFile -parent . -initialdir $home ]
   if { [string compare $filename ""] } {
      set f [open $filename w]
      puts -nonewline $f $meldung
      close $f        
   }
}

#============================================================
#
# Procedure: ui_turnierdat_display
#
# Purpose: Ausgabe der allgemeinen Daten des Turnieres
#
# Preconditions: 
#   Turnier geffnet. Alle Parameter sind gefllt.
#
# Postconditions:
#  Inhalt der Parameter sind ins Hauptwindow geschrieben.
#
# Globals: keine
#
# Returns: 0 = success
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Anzeigen des Turnierverzeichnisses
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------

proc ui_turnierdat_display { Tid Tname Spielnum ArraySpielleiter } {
   global turdir

   upvar $ArraySpielleiter Spielleiter

   set l_r .turnierdaten.turnier
   set l_s .turnierdaten.spielleiter

   $l_r.beschreibung.val configure  -text $Tname -anchor w 
   $l_r.anzahlspieler.val configure  -text $Spielnum -anchor w 
   $l_r.siegpunkte.val    configure -text $Spielleiter(Siegpunkte) -anchor w 
   $l_r.globaltid.val configure  -text $Spielleiter(globaltid) -anchor w 
   $l_r.tid.val configure  -text $turdir/$Tid -anchor w 
   $l_s.name.val configure  -text $Spielleiter(Name) -anchor w 
   $l_s.strasse.val configure  -text $Spielleiter(Strasse) -anchor w 
   $l_s.wohnort.val configure  -text $Spielleiter(Wohnort) -anchor w 
   $l_s.telefon.val configure  -text $Spielleiter(Telefon) -anchor w 
   $l_s.fax.val  configure  -text $Spielleiter(FAX) -anchor w 
   $l_s.mail.val configure  -text $Spielleiter(Mail) -anchor w 

   return 0
}

#============================================================
#
# Procedure: ui_turnier_clear
#
# Purpose: Lschen der Ausgabe der allgemeinen Daten des Turnieres
#
# Preconditions: 
#   Hauptwindow mu vorhanden sein.
#
# Postconditions:
#  Inhalt der Anzeigefelder ist leer
#
# Globals: keine
#
# Returns: 0 = success
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Lschen der Anzeige im Feld tid
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------

proc ui_turnier_clear { } {

   set l_r .turnierdaten.turnier
   set l_s .turnierdaten.spielleiter

   $l_r.beschreibung.val   configure  -text "" -anchor w 
   $l_r.anzahlspieler.val  configure  -text "" -anchor w 
   $l_r.siegpunkte.val     configure  -text "" -anchor w 
   $l_r.globaltid.val      configure  -text "" -anchor w 
   $l_r.tid.val            configure  -text "" -anchor w 
   $l_s.name.val           configure  -text "" -anchor w 
   $l_s.strasse.val        configure  -text "" -anchor w 
   $l_s.wohnort.val        configure  -text "" -anchor w 
   $l_s.telefon.val        configure  -text "" -anchor w 
   $l_s.fax.val            configure  -text "" -anchor w 
   $l_s.mail.val           configure  -text "" -anchor w 
   .mannschaftundrunden.mannschaft.mannschaft delete 0 end
   .mannschaftundrunden.runden.runden         delete 0 end

   return 0
}


#============================================================
#                          
# Procedure: ui_runde_getsel                         
#
# Purpose: Holen der aktuell selektierten Runde 
#
# Preconditions: 
#   Hauptwindow mu vorhanden sein. In der Listbox der Runden muss eine
#   Zeile ausgewaehlt sein.
#
# Postconditions:
#  Index und Inhalt des selektierten Datensatzes wird zurueckgeliefert.
#
# Globals: keine
#
# Returns: 0 = success                   
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Bug fixing, Fehlerbehandlung bei der Selection
#-------------------------------------------------------

proc ui_runde_getsel { VarRunde VarDatum } {
   upvar $VarRunde Runde
   upvar $VarDatum Rundendatum

   set r .mannschaftundrunden.runden.runden
   set selected_object [selection own]
   set err [ catch { set selected_row [selection get] } ]
   if { $err == 0 } {
      set selected_runde [string trim $selected_row \{\} ]
      if { [string compare $selected_object $r] == 0 } {
         set Runde [string trim [lindex $selected_runde 0] ]
         set Rundendatum [lrange $selected_runde 1 end]
         return 0
      }
   }
   return 1
}

#============================================================
#
# Procedure: ui_mannschaft_getsel
#
# Purpose: Holen der aktuell selektierten Mannschaft
#
# Preconditions: 
#   Hauptwindow mu vorhanden sein. In der Listbox der Mannschaften muss eine
#   Zeile ausgewaehlt sein.
#
# Postconditions:
#  Index und Inhalt des selektierten Datensatzes wird zurueckgeliefert.
#
# Globals: keine
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Bug fixing, Fehlerbehandlung bei der Selection
#-------------------------------------------------------

proc ui_mannschaft_getsel { VarNr VarMid VarName VarHeimspieltag } {
   upvar $VarNr Nr
   upvar $VarMid Mid
   upvar $VarName Name
   upvar $VarHeimspieltag Heimspieltag

   set s [db_Tid_get Tname Tid]
   set r .mannschaftundrunden.mannschaft.mannschaft
   set selected_object [selection own]
   set err [ catch { set selected_row [selection get] } ]
   if { $err == 0 } {
      set selected_mannschaft [string trim $selected_row \{\} ]
      if { [string compare $selected_object $r] == 0 } {
         set Nr [string trim [lindex $selected_mannschaft 0] ]
         set s [db_mannschaft_selall $Tid mannschaften]
         set Mid [lindex $mannschaften($Nr) 0]
         set Name [lindex $mannschaften($Nr) 1]
         set Heimspieltag [lindex $mannschaften($Nr) 2]
         return 0
      }
   } 
   return 1
}

#============================================================
#
# Procedure: ui_wettkampf_getsel
#
# Purpose: Holen des aktuell selektierten Wettkampfes
#
# Preconditions: 
#   Wettkampfwindow mu vorhanden sein. In der Listbox der Wettkmpfe muss eine
#   Zeile ausgewaehlt sein.
#
# Postconditions:
#  Index des selektierten Datensatzes wird zurckgeliefert.
#
# Globals: keine
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Bug fixing, Fehlerbehandlung bei der Selection
#-------------------------------------------------------

proc ui_wettkampf_getsel { Varwettkampfnr } {
   upvar $Varwettkampfnr wettkampfnr

   set r .runde_eingabe.frame.list

   set selected_object [selection own]
   set err [ catch { set selected_row [selection get] } ]
   if { $err == 0 } {
      set selected_wettkampf [string trim $selected_row \{\} ]
      if { [string compare $selected_object $r] == 0 } {
         set wettkampfnr [string trim [lindex $selected_wettkampf 0] ]
         return 0
      }
   }
   return 1
}

#============================================================
#
# Procedure: ui_spielplan_display
#
# Purpose: Anzeigen des Spielplanes
#
# Preconditions: 
#  Turnier mu geffnet sein. Spielplan mu existieren.
#
# Postconditions:
#  Spielplan ist in eigenem Window angezeigt.
#
# Globals: 
#  turdir
#  spielplanfile
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Einbau der Funktion Save
#
#-------------------------------------------------------

proc ui_spielplan_display { Tid } {
   # Globals
   global turdir
   global spielplanfile

   set w .spielplan
   set planfenster $w.text
   catch {destroy $w}

   set s [db_spielplan_selall $Tid spielplan]

   toplevel $w
   wm title $w "Spielplan: $turdir/$Tid/$spielplanfile"
                   
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "ui_spielplan_store"
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.save $w.buttons.cancel -side left -expand true
           
   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" -setgrid 1 \
     -height 30 
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   $w.text insert end $spielplan
   return 0
}

#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Zusatzfunktion zum Speichern des Spielplanes
#
#-------------------------------------------------------

proc ui_spielplan_store { } {
global env

   # Aufbau des UIs
   set w .spielplan
   set spielplan [$w.text get 0.0 end]
   set filename [tk_getSaveFile -parent . -initialdir $env(HOME) ]
   if { [ string compare $filename ""] } {
      set f [open $filename w]
      puts -nonewline $f $spielplan
      close $f        
   }
   return 0
}
#============================================================
#
# Procedure: ui_runde_eingabe
#
# Purpose: Window zur Steuerung der Eingabe der Einzelergebnisse
#
# Preconditions: 
#  Erhaltene Parameter "Runde" und "Tid" sind mit gltigen Werten besetzt
#
# Postconditions:
#  Begegnungen der erhaltenen Runde werden mit bisher bekannten 
#  Ergebnissen in Window angezeigt.
#
# Globals: 
#  geom65
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================

proc ui_runde_eingabe { Tid Runde } {
   # Globals
   global geom65 

   set w .runde_eingabe
   catch {destroy $w}
   toplevel $w
   wm title $w "Ergebnisse der Runde $Runde"
                      
   message $w.msg -aspect 500 \
   -text "Aus den angezeigten Mannschaftskmpfen bitte einen \
          mit MB1 auswhlen. Einzelergebnisse mit OK oder mit Doppel-MB1,
          kampflose Wettkmpfe mit rechter Maustaste."

   frame $w.frame
   frame $w.buttons
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill both
   pack  $w.buttons -side bottom -fill x -pady 2m

   scrollbar $w.frame.scroll -relief sunken -command "$w.frame.list yview"
   set befehl1 "listbox $w.frame.list -yscrollcommand {$w.frame.scroll set} -relief sunken"
   set befehl2 "-setgrid 1 $geom65"
   eval [concat $befehl1 $befehl2]

   pack $w.frame.scroll -side right -fill y -expand yes
   pack $w.frame.list -side left -expand yes -fill both
   button $w.buttons.einzel -text "Einzelergebnisse" \
       -command "cn_wettkampf_eingabe $Tid $Runde"
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"

   pack $w.buttons.einzel -side left -expand true
   pack $w.buttons.cancel -side left -expand true
            
   set s [db_mannschaft_selall $Tid mannschaft]
   set s [db_runde_load $Tid $Runde wettkampf]              
           
   set s [ui_runde_anzeige wettkampf mannschaft]
   bind $w.frame.list <Double-Button-1> "cn_wettkampf_eingabe $Tid $Runde"
#--------------------------------------------------------
# Changed:  5-MAY-1997     
# Name: G.Niklaus
# Reason: Kampflose Ergebnisse mit rechter Maustaste
#-------------------------------------------------------
   bind $w.frame.list <Button-3> "cn_wettkampf_kampflos $Tid $Runde"
   return 0
}


#============================================================
#
# Procedure: ui_kreuztabelle_display
#
# Purpose: Anzeigen der Kreuztabelle
#
# Preconditions: 
#  Turnier mu geffnet sein. Spielplan mu existieren.
#
# Postconditions:
#  Kreuztabelle wird in eigenem Window angezeigt.
#
# Globals: 
#  wettkaempfe
#  ergebnisse
#  turdir
#  spielplanfile
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================

proc ui_kreuztabelle_display { Tid } {
   # Globals
   global turdir
   global spielplanfile
   global wettkaempfe
   global id_index

   catch {unset id_index}

   set cellwidth 1.5
   set mannwidth 4
   set xoffset 0.1
   set yoffset 0.1

   set w .kreuztabelle
   set kreuzfenster $w.c.kreuz
   catch {destroy $w}

   set s [db_mannschaft_selall $Tid mannschaften]

   # Bestimmen der Anzahl der Mannschaften und zu spielenden Runden
   set MAnzahl [array size mannschaften]
   set TlnAnzahl $MAnzahl
   if { ($TlnAnzahl & 1 ) == 1 } {
      incr TlnAnzahl
   }

   set cw [expr $TlnAnzahl*$cellwidth+$mannwidth+$xoffset+$xoffset]
   set ch [expr $TlnAnzahl*$cellwidth+$yoffset+$yoffset]


   toplevel $w    
   wm title $w "Kreuztabelle"
   frame $w.c
   pack $w.c -side top -fill both -expand yes

   canvas $w.c.kreuz -relief sunken -borderwidth 2 \
          -width ${cw}c -height ${ch}c \
          -xscrollcommand "$w.c.hscroll set" \
          -yscrollcommand "$w.c.vscroll set"
   
   scrollbar $w.c.vscroll -orient vertical   -command "$kreuzfenster yview"
   scrollbar $w.c.hscroll -orient horizontal -command "$kreuzfenster xview"
                                                
   $kreuzfenster configure -scrollregion " 0 0 ${cw}c ${ch}c "

   pack $w.c.hscroll -side bottom -fill x
   pack $w.c.vscroll -side right -fill y 
   pack $kreuzfenster -fill both -expand yes
#   pack $w.c.hscroll -side bottom -fill both -expand yes

#   grid $kreuzfenster -in $w.c -row 0 -column 0 -rowspan 1 -columnspan 1 -sticky news
#   grid $w.c.vscroll -row 0 -column 1 -rowspan 1 -columnspan 1 -sticky news
#   grid $w.c.hscroll -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
#   grid rowconfig    $w.c 0 -weight 1 -minsize 0
#   grid columnconfig $w.c 0 -weight 1 -minsize 0

#   $kreuzfenster bind all <Any-Enter> "scrollEnter $kreuzfenster"
#   $kreuzfenster bind all <Any-Leave> "scrollLeave $kreuzfenster"
   $kreuzfenster bind all <1> "scrollButton $kreuzfenster"
   $kreuzfenster bind all <3> "scrollButton_kl $kreuzfenster"

#   pack $kreuzfenster

# Mannschaften darstellen
   for {set j 0} { $j < $MAnzahl} { incr j } {
      set mymannschaft [lindex $mannschaften([expr $j+1]) 1]
      set x1 $xoffset
      set y1 [expr $j*$cellwidth+$yoffset]
      set x2 $mannwidth
      set y2 [expr $j*$cellwidth+$cellwidth+$yoffset]
      $kreuzfenster create rectangle ${x1}c ${y1}c ${x2}c ${y2}c -width 0.2m \
      -fill yellow -tags square
      $kreuzfenster create text [expr $x1+$xoffset]c [expr $y2-$yoffset]c \
      -anchor sw -text "$mymannschaft" -tags text
   }

# Begegnungen darstellen
   foreach k [array names wettkaempfe] {
#     puts "$k $wettkaempfe($k)"
      set myrunde [lindex $wettkaempfe($k) 0]
      set mytext1  [string trim [lindex $wettkaempfe($k) 5] ]
      set mytext   [string trim [lindex $wettkaempfe($k) 6] ]
      set i       [lindex $wettkaempfe($k) 2]
      set j       [lindex $wettkaempfe($k) 3]
      set mycol yellow

      set x1 [expr ($i-1)*$cellwidth+$mannwidth]
      set y1 [expr ($j-1)*$cellwidth+$yoffset]
      set x2 [expr ($i-1)*$cellwidth+$mannwidth+$cellwidth]
      set y2 [expr ($j-1)*$cellwidth+$cellwidth+$yoffset]
      if {$i == $j} {set mycol black}
                                                
      $kreuzfenster create rectangle ${x1}c ${y1}c ${x2}c ${y2}c -width 0.2m \
         -fill $mycol
      $kreuzfenster create text [expr $x1+$xoffset]c [expr $y2-$yoffset]c \
      -anchor sw -text "R$myrunde" 
      set textid [$kreuzfenster create text [expr $x1+$xoffset]c [expr $y1+5*$yoffset]c \
      -anchor sw -text "$mytext" -fill red]

      set x1 [expr ($j-1)*$cellwidth+$mannwidth]
      set y1 [expr ($i-1)*$cellwidth+$yoffset]
      set x2 [expr ($j-1)*$cellwidth+$mannwidth+$cellwidth]
      set y2 [expr ($i-1)*$cellwidth+$cellwidth+$yoffset]
      if {$i == $j} {set mycol black}
                                                
      $kreuzfenster create rectangle ${x1}c ${y1}c ${x2}c ${y2}c -width 0.2m \
         -fill $mycol
      $kreuzfenster create text [expr $x1+$xoffset]c [expr $y2-$yoffset]c \
      -anchor sw -text "R$myrunde"
      set textid1 [$kreuzfenster create text [expr $x1+$xoffset]c [expr $y1+5*$yoffset]c \
      -anchor sw -text "$mytext1" -fill red]
      set id_index($textid) $k
      set id_index($textid1) $k
   }
   return 0
}
                           
proc scrollEnter canvas {
   global oldFill
   set id [$canvas find withtag current]
#   puts "Entering $id"
#   set oldFill [lindex [$canvas itemconfig $id -fill] 4]
#   if {[winfo depth $canvas] > 1 } {
#      $canvas itemconfigure $id -fill SeaGreen1
#   }
}

proc scrollLeave canvas {
   global oldFill
   set id [$canvas find withtag current]
#   puts "Leaving $id"
   $canvas itemconfigure $id -fill $oldFill
}

proc scrollButton canvas {
   global wettkaempfe
   global id_index
   global oldFill
   set id [$canvas find withtag current]
   set error [catch {set k $id_index($id)}]
   if {$error == 0} {
#      puts "Bin gerade ueber $id, Wettkampf = $wettkaempfe($k) "
      set s [db_Tid_get Tname Tid]
      set wettkampfnr [lindex $wettkaempfe($k) 1]
      set runde       [lindex $wettkaempfe($k) 0]
      set s [ui_wettkampf_eingabe $Tid $runde $wettkampfnr]
   }
}

proc scrollButton_kl canvas {
   global wettkaempfe
   global id_index
   global oldFill
   set id [$canvas find withtag current]
   set error [catch {set k $id_index($id)}]
   if {$error == 0} {
#      puts "Bin gerade ueber $id, Wettkampf = $wettkaempfe($k) "
      set s [db_Tid_get Tname Tid]
      set wettkampfnr [lindex $wettkaempfe($k) 1]
      set runde       [lindex $wettkaempfe($k) 0]
      set s [ui_wettkampf_kampflos $Tid $runde $wettkampfnr]
   }
}
