#============================================================
#
# Procedure: ui_rundenbericht_display
#
# Purpose: Anzeige/Eingabe des Rundenberichtes
#
# Preconditions: 
#  Variable Rundenbericht enthlt den Bericht
#
# Postconditions:
#  Der Bericht wird im UI dargestellt.
#  Das UI ist eine tk-Builtin Funktion
#
# Globals:
#
# Returns: Keine
#
#=============================================================
#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Anzeigen des Dateinamens des Rundenberichtes
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Einfuegen Funktion Save
#
#-------------------------------------------------------

proc ui_rundenbericht_display { Tid Rundenbericht dateiname } {

   set Titel "Rundenbericht"

   # Aufbau des UIs
   set w .ui_rundenbericht_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel: $dateiname"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text Speichern -command "ui_rundenbericht_store"
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
#   pack $w.buttons.cancel -side left -expand true
   pack $w.buttons.save $w.buttons.cancel -side left -expand true
                             
   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung des Rundenberichtes
   $w.text insert end $Rundenbericht
}
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Neue Funktion zum Speichern des Rundenberichtes
#
#-------------------------------------------------------
proc ui_rundenbericht_store { } {
global env                     

   # Aufbau des UIs
   set w .ui_rundenbericht_display
   set Rundenbericht [$w.text get 0.0 end]
   set filename [tk_getSaveFile -parent . -initialdir $env(HOME) ]
   if { [ string compare $filename ""] } {
      set f [open $filename w]
      puts -nonewline $f $Rundenbericht
      close $f        
   }
   return 0
}

#============================================================
#
# Procedure: ui_releasenotes_display
#
# Purpose: Anzeige der Releasenotes
#
# Preconditions: 
#  Variable "Releasenotes" enthlt die Releasenotes
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die Release Notes werden im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================

proc ui_releasenotes_display { Releasenotes } {

   set Titel "Release Notes"

   # Aufbau des UIs
   set w .ui_releasenotes_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung der Releasenotes
   $w.text insert end $Releasenotes
}

#============================================================
#
# Procedure: ui_usersguide_display
#
# Purpose: Anzeige des User Guide
#
# Preconditions: 
#  Variable "Guide" enthlt den User Guide
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Guide wird im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#
# Returns: Keine
#
#=============================================================
                            
proc ui_usersguide_display { Guide } {

   set Titel "User's Guide"

   # Aufbau des UIs
   set w .ui_usersguide_display
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.cancel -text "Beenden" -command "destroy $w"
   pack $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 30
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung 
   $w.text insert end $Guide
   return 0
}

#============================================================
#
# Procedure: ui_spielplan_anhang_enter
#
# Purpose: Anzeige/Eingabe des Anhanges zum Spielplan
#
# Preconditions: 
#  Turnier mu geffnet sein. Tid enthlt die Turnier-ID
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Anhang wird im UI dargestellt und in Datei
#  gespeichert
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine
#
#=============================================================

proc ui_spielplan_anhang_enter { Tid } {

   # Holen des evtl. vorhandenen Anhangs

   set s [db_spielplan_anhang_selall $Tid Spielplan_Anhang Dateiname]
   set Titel "Anhang an Spielplan: $Dateiname"

   # Aufbau des UIs
   set w .ui_spielplan_anhang_enter
   catch {destroy $w}
   toplevel $w  
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "db_spielplan_anhang_store $Tid; destroy $w"
   button $w.buttons.cancel -text "Abbrechen" -command "destroy $w"
   pack $w.buttons.save $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 10
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung des Anhang
   $w.text insert end $Spielplan_Anhang
}

#============================================================
#
# Procedure: ui_rundenbericht_anhang_enter
#
# Purpose: Anzeige/Eingabe des Anhanges zum Rundenbericht
#
# Preconditions: 
#  Turnier mu geffnet sein. Tid enthlt die Turnier-ID
#  Runde mu ausgewhlt sein. Runde enthlt die ausgewhlte Runde
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Der Anhang wird im UI dargestellt und in Datei
#  gespeichert
#  Das UI ist ein separates Window.
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================

proc ui_rundenbericht_anhang_enter { Tid Runde } {
                          
   # Holen des evtl. vorhandenen Anhangs

   set s [db_rundenbericht_anhang_selall $Tid $Runde Runden_Anhang Dateiname]
   set Titel "Anhang an Rundenbericht: $Dateiname"

   # Aufbau des UIs
   set w .ui_rundenbericht_anhang_enter
   catch {destroy $w}
   toplevel $w  
   wm title $w "$Titel"
   wm minsize $w 1 1
     
   frame $w.buttons
   pack  $w.buttons -side bottom -fill x -pady 2m
   button $w.buttons.save -text "Speichern" -command "db_rundenbericht_anhang_store $Tid $Runde; destroy $w"
   button $w.buttons.cancel -text "Abbrechen" -command "destroy $w"
   pack $w.buttons.save $w.buttons.cancel -side left -expand true

   text $w.text -relief sunken -bd 2 -yscrollcommand "$w.scroll set" \
        -setgrid 1 -height 10
   scrollbar $w.scroll -command "$w.text yview"
   pack $w.scroll -side left -fill y
   pack $w.text -expand yes -fill both

   # Darstellung des Anhang
   $w.text insert end $Runden_Anhang
}


#============================================================
#
# Procedure: ui_turnier_export
#
# Purpose: Anzeige/Eingabe zum Exportieren eines Turnieres
#
# Preconditions: 
#  Turnier darf nicht geffnet sein. Tid enthlt die Turnier-ID
#  des zu exportierenden Turnieres.
#
# Postconditions:
#  Der Dateiname, in das das Turnier exportiert werden
#  soll, wird abgefragt.
#  Das UI ist ein tk-Builtin Funktion
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================
#--------------------------------------------------------
# Changed: 25-FEB-1999
# Name: G.Niklaus
# Reason: Einfuegen der File Selection Box (Save)
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  7-SEP-1999
# Name: G.Niklaus
# Reason: Kurze Dateinamen fuer DOS /W95
#
#-------------------------------------------------------

proc ui_turnier_export { Tid } {

global G_exportdatei
global env                     

   # Aufbau des UIs
   set w .
   set filename t_$Tid.zip
   set G_exportdatei [tk_getSaveFile -parent . -initialdir $env(HOME) -initialfile $filename]
   if { [ string compare $G_exportdatei ""] } {
      db_turnier_export $Tid 
   }
   return 0
}

#============================================================
#
# Procedure: ui_turnier_import
#
# Purpose: Anzeige/Eingabe zum Importieren eines Turnieres
#
# Preconditions: 
#  Turnier darf nicht geffnet sein. Tid enthlt die Turnier-ID
#  des Turnieres, das mit den importierten Daten berschrieben 
#  wird.
#
# Postconditions:
#  Der Dateiname, von dem das Turnier importiert werden
#  soll, wird abgefragt.
#  Das UI ist ein tk-Builtin Funktion
#                          
# Globals:
#
# Returns: Keine                                         
#
#=============================================================

proc ui_turnier_import { Tid } {

global G_exportdatei
global env
                     
   # Aufbau des UIs
   set w .

   set G_exportdatei [tk_getOpenFile -parent . -initialdir $env(HOME) ]
   if { [ string compare $G_exportdatei ""] } {
      db_turnier_import $Tid 
   }
   return 0
}
